@@ -6,9 +6,9 @@ Type annotations for codedeploy service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_codedeploy.literals import ApplicationRevisionSortBy
+    from mypy_boto3_codedeploy.literals import ApplicationRevisionSortByType
 
-    data: ApplicationRevisionSortBy = "firstUsedTime"
+    data: ApplicationRevisionSortByType = "firstUsedTime"
     ```
 """
 import sys
@@ -20,27 +20,27 @@ else:
 
 
 __all__ = (
-    "ApplicationRevisionSortBy",
-    "AutoRollbackEvent",
-    "BundleType",
-    "ComputePlatform",
-    "DeploymentCreator",
-    "DeploymentOption",
-    "DeploymentReadyAction",
-    "DeploymentStatus",
+    "ApplicationRevisionSortByType",
+    "AutoRollbackEventType",
+    "BundleTypeType",
+    "ComputePlatformType",
+    "DeploymentCreatorType",
+    "DeploymentOptionType",
+    "DeploymentReadyActionType",
+    "DeploymentStatusType",
     "DeploymentSuccessfulWaiterName",
-    "DeploymentTargetType",
-    "DeploymentType",
-    "DeploymentWaitType",
-    "EC2TagFilterType",
-    "ErrorCode",
-    "FileExistsBehavior",
-    "GreenFleetProvisioningAction",
-    "InstanceAction",
-    "InstanceStatus",
-    "InstanceType",
-    "LifecycleErrorCode",
-    "LifecycleEventStatus",
+    "DeploymentTargetTypeType",
+    "DeploymentTypeType",
+    "DeploymentWaitTypeType",
+    "EC2TagFilterTypeType",
+    "ErrorCodeType",
+    "FileExistsBehaviorType",
+    "GreenFleetProvisioningActionType",
+    "InstanceActionType",
+    "InstanceStatusType",
+    "InstanceTypeType",
+    "LifecycleErrorCodeType",
+    "LifecycleEventStatusType",
     "ListApplicationRevisionsPaginatorName",
     "ListApplicationsPaginatorName",
     "ListDeploymentConfigsPaginatorName",
@@ -50,29 +50,29 @@ __all__ = (
     "ListDeploymentsPaginatorName",
     "ListGitHubAccountTokenNamesPaginatorName",
     "ListOnPremisesInstancesPaginatorName",
-    "ListStateFilterAction",
-    "MinimumHealthyHostsType",
-    "OutdatedInstancesStrategy",
-    "RegistrationStatus",
-    "RevisionLocationType",
-    "SortOrder",
-    "StopStatus",
-    "TagFilterType",
-    "TargetFilterName",
-    "TargetLabel",
-    "TargetStatus",
-    "TrafficRoutingType",
-    "TriggerEventType",
+    "ListStateFilterActionType",
+    "MinimumHealthyHostsTypeType",
+    "OutdatedInstancesStrategyType",
+    "RegistrationStatusType",
+    "RevisionLocationTypeType",
+    "SortOrderType",
+    "StopStatusType",
+    "TagFilterTypeType",
+    "TargetFilterNameType",
+    "TargetLabelType",
+    "TargetStatusType",
+    "TrafficRoutingTypeType",
+    "TriggerEventTypeType",
 )
 
 
-ApplicationRevisionSortBy = Literal["firstUsedTime", "lastUsedTime", "registerTime"]
-AutoRollbackEvent = Literal[
+ApplicationRevisionSortByType = Literal["firstUsedTime", "lastUsedTime", "registerTime"]
+AutoRollbackEventType = Literal[
     "DEPLOYMENT_FAILURE", "DEPLOYMENT_STOP_ON_ALARM", "DEPLOYMENT_STOP_ON_REQUEST"
 ]
-BundleType = Literal["JSON", "YAML", "tar", "tgz", "zip"]
-ComputePlatform = Literal["ECS", "Lambda", "Server"]
-DeploymentCreator = Literal[
+BundleTypeType = Literal["JSON", "YAML", "tar", "tgz", "zip"]
+ComputePlatformType = Literal["ECS", "Lambda", "Server"]
+DeploymentCreatorType = Literal[
     "CloudFormation",
     "CloudFormationRollback",
     "CodeDeploy",
@@ -81,19 +81,19 @@ DeploymentCreator = Literal[
     "codeDeployRollback",
     "user",
 ]
-DeploymentOption = Literal["WITHOUT_TRAFFIC_CONTROL", "WITH_TRAFFIC_CONTROL"]
-DeploymentReadyAction = Literal["CONTINUE_DEPLOYMENT", "STOP_DEPLOYMENT"]
-DeploymentStatus = Literal[
+DeploymentOptionType = Literal["WITHOUT_TRAFFIC_CONTROL", "WITH_TRAFFIC_CONTROL"]
+DeploymentReadyActionType = Literal["CONTINUE_DEPLOYMENT", "STOP_DEPLOYMENT"]
+DeploymentStatusType = Literal[
     "Baking", "Created", "Failed", "InProgress", "Queued", "Ready", "Stopped", "Succeeded"
 ]
 DeploymentSuccessfulWaiterName = Literal["deployment_successful"]
-DeploymentTargetType = Literal[
+DeploymentTargetTypeType = Literal[
     "CloudFormationTarget", "ECSTarget", "InstanceTarget", "LambdaTarget"
 ]
-DeploymentType = Literal["BLUE_GREEN", "IN_PLACE"]
-DeploymentWaitType = Literal["READY_WAIT", "TERMINATION_WAIT"]
-EC2TagFilterType = Literal["KEY_AND_VALUE", "KEY_ONLY", "VALUE_ONLY"]
-ErrorCode = Literal[
+DeploymentTypeType = Literal["BLUE_GREEN", "IN_PLACE"]
+DeploymentWaitTypeType = Literal["READY_WAIT", "TERMINATION_WAIT"]
+EC2TagFilterTypeType = Literal["KEY_AND_VALUE", "KEY_ONLY", "VALUE_ONLY"]
+ErrorCodeType = Literal[
     "AGENT_ISSUE",
     "ALARM_ACTIVE",
     "APPLICATION_MISSING",
@@ -129,14 +129,14 @@ ErrorCode = Literal[
     "THROTTLED",
     "TIMEOUT",
 ]
-FileExistsBehavior = Literal["DISALLOW", "OVERWRITE", "RETAIN"]
-GreenFleetProvisioningAction = Literal["COPY_AUTO_SCALING_GROUP", "DISCOVER_EXISTING"]
-InstanceAction = Literal["KEEP_ALIVE", "TERMINATE"]
-InstanceStatus = Literal[
+FileExistsBehaviorType = Literal["DISALLOW", "OVERWRITE", "RETAIN"]
+GreenFleetProvisioningActionType = Literal["COPY_AUTO_SCALING_GROUP", "DISCOVER_EXISTING"]
+InstanceActionType = Literal["KEEP_ALIVE", "TERMINATE"]
+InstanceStatusType = Literal[
     "Failed", "InProgress", "Pending", "Ready", "Skipped", "Succeeded", "Unknown"
 ]
-InstanceType = Literal["Blue", "Green"]
-LifecycleErrorCode = Literal[
+InstanceTypeType = Literal["Blue", "Green"]
+LifecycleErrorCodeType = Literal[
     "ScriptFailed",
     "ScriptMissing",
     "ScriptNotExecutable",
@@ -144,7 +144,9 @@ LifecycleErrorCode = Literal[
     "Success",
     "UnknownError",
 ]
-LifecycleEventStatus = Literal["Failed", "InProgress", "Pending", "Skipped", "Succeeded", "Unknown"]
+LifecycleEventStatusType = Literal[
+    "Failed", "InProgress", "Pending", "Skipped", "Succeeded", "Unknown"
+]
 ListApplicationRevisionsPaginatorName = Literal["list_application_revisions"]
 ListApplicationsPaginatorName = Literal["list_applications"]
 ListDeploymentConfigsPaginatorName = Literal["list_deployment_configs"]
@@ -154,21 +156,21 @@ ListDeploymentTargetsPaginatorName = Literal["list_deployment_targets"]
 ListDeploymentsPaginatorName = Literal["list_deployments"]
 ListGitHubAccountTokenNamesPaginatorName = Literal["list_git_hub_account_token_names"]
 ListOnPremisesInstancesPaginatorName = Literal["list_on_premises_instances"]
-ListStateFilterAction = Literal["exclude", "ignore", "include"]
-MinimumHealthyHostsType = Literal["FLEET_PERCENT", "HOST_COUNT"]
-OutdatedInstancesStrategy = Literal["IGNORE", "UPDATE"]
-RegistrationStatus = Literal["Deregistered", "Registered"]
-RevisionLocationType = Literal["AppSpecContent", "GitHub", "S3", "String"]
-SortOrder = Literal["ascending", "descending"]
-StopStatus = Literal["Pending", "Succeeded"]
-TagFilterType = Literal["KEY_AND_VALUE", "KEY_ONLY", "VALUE_ONLY"]
-TargetFilterName = Literal["ServerInstanceLabel", "TargetStatus"]
-TargetLabel = Literal["Blue", "Green"]
-TargetStatus = Literal[
+ListStateFilterActionType = Literal["exclude", "ignore", "include"]
+MinimumHealthyHostsTypeType = Literal["FLEET_PERCENT", "HOST_COUNT"]
+OutdatedInstancesStrategyType = Literal["IGNORE", "UPDATE"]
+RegistrationStatusType = Literal["Deregistered", "Registered"]
+RevisionLocationTypeType = Literal["AppSpecContent", "GitHub", "S3", "String"]
+SortOrderType = Literal["ascending", "descending"]
+StopStatusType = Literal["Pending", "Succeeded"]
+TagFilterTypeType = Literal["KEY_AND_VALUE", "KEY_ONLY", "VALUE_ONLY"]
+TargetFilterNameType = Literal["ServerInstanceLabel", "TargetStatus"]
+TargetLabelType = Literal["Blue", "Green"]
+TargetStatusType = Literal[
     "Failed", "InProgress", "Pending", "Ready", "Skipped", "Succeeded", "Unknown"
 ]
-TrafficRoutingType = Literal["AllAtOnce", "TimeBasedCanary", "TimeBasedLinear"]
-TriggerEventType = Literal[
+TrafficRoutingTypeType = Literal["AllAtOnce", "TimeBasedCanary", "TimeBasedLinear"]
+TriggerEventTypeType = Literal[
     "DeploymentFailure",
     "DeploymentReady",
     "DeploymentRollback",
